#!/bin/bash
#
# Resolve the location of the DeepGit installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
        PRG="$link"
    else
        PRG="`dirname "$PRG"`/$link"
    fi
done

DEEPGIT_BIN=`dirname "$PRG"`

# absolutize dir
oldpwd=`pwd`
cd "${DEEPGIT_BIN}"
DEEPGIT_BIN=`pwd`
cd "${oldpwd}"

ICON_NAME=syntevo-deepgit
TMP_DIR=`mktemp --directory`
DESKTOP_FILE=$TMP_DIR/syntevo-deepgit.desktop
cat << EOF > $DESKTOP_FILE
[Desktop Entry]
Version=1.0
Encoding=UTF-8
Name=DeepGit
Keywords=git;hg;svn;mercurial;subversion
GenericName=Git&Hg-Client + SVN-support
Type=Application
Categories=Development;RevisionControl
Terminal=false
StartupNotify=true
StartupWMClass=DeepGit
Exec="$DEEPGIT_BIN/deepgit.sh" %u
MimeType=x-scheme-handler/deepgit;x-scheme-handler/sourcetree;
Icon=$ICON_NAME.png
EOF

# seems necessary to refresh immediately:
chmod 644 $DESKTOP_FILE

xdg-desktop-menu install $DESKTOP_FILE
xdg-icon-resource install --size  32 "$DEEPGIT_BIN/deepgit-32.png"  $ICON_NAME
xdg-icon-resource install --size  48 "$DEEPGIT_BIN/deepgit-48.png"  $ICON_NAME
xdg-icon-resource install --size  64 "$DEEPGIT_BIN/deepgit-64.png"  $ICON_NAME
xdg-icon-resource install --size 128 "$DEEPGIT_BIN/deepgit-128.png" $ICON_NAME

rm $DESKTOP_FILE
rm -R $TMP_DIR
